@@ -6,7 +6,7 @@
 #' @param arg A function argument to be checked
 #' @param required_vars A list of variables created using `exprs()`
 #' @param check_is_grouped Throw an error is `dataset` is grouped? Defaults to `TRUE`.
-#' @param optional Is the checked parameter optional? If set to `FALSE` and `arg`
+#' @param optional Is the checked argument optional? If set to `FALSE` and `arg`
 #' is `NULL` then an error is thrown
 #'
 #'
@@ -92,7 +92,7 @@ assert_data_frame <- function(arg,
 #' @param case_sensitive Should the argument be handled case-sensitive?
 #' If set to `FALSE`, the argument is converted to lower case for checking the
 #' permitted values and returning the argument.
-#' @param optional Is the checked parameter optional? If set to `FALSE` and `arg`
+#' @param optional Is the checked argument optional? If set to `FALSE` and `arg`
 #' is `NULL` then an error is thrown
 #'
 #'
@@ -116,7 +116,7 @@ assert_data_frame <- function(arg,
 #'
 #' try(example_fun(TRUE))
 #'
-#' # handling parameters case-insensitive
+#' # handling arguments case-insensitive
 #' example_fun2 <- function(msg_type) {
 #'   msg_type <- assert_character_scalar(
 #'     msg_type,
@@ -202,7 +202,7 @@ assert_character_scalar <- function(arg,
 #' @param values A `character` vector of valid values for `arg`
 #' @param named If set to `TRUE`, an error is issued if not all elements of the
 #'   vector are named.
-#' @param optional Is the checked parameter optional? If set to `FALSE` and `arg`
+#' @param optional Is the checked argument optional? If set to `FALSE` and `arg`
 #' is `NULL` then an error is thrown
 #'
 #'
@@ -260,20 +260,8 @@ assert_character_vector <- function(arg, values = NULL, named = FALSE, optional
     }
   }
 
-  if (named && length(arg) > 0) {
-    if (is.null(names(arg))) {
-      abort(paste0(
-        "All elements of ", arg_name(substitute(arg)), " must be named.\n",
-        "No element is named."
-      ))
-    }
-    unnamed <- which(names(arg) == "")
-    if (length(unnamed) > 0) {
-      abort(paste0(
-        "All elements of ", arg_name(substitute(arg)), " must be named.\n",
-        "The following elements are not named: ", enumerate(unnamed, quote_fun = NULL)
-      ))
-    }
+  if (named) {
+    assert_named(arg)
   }
 }
 
@@ -283,7 +271,7 @@ assert_character_vector <- function(arg, values = NULL, named = FALSE, optional
 #'
 #' @param arg A function argument to be checked
 #'
-#' @param optional Is the checked parameter optional?
+#' @param optional Is the checked argument optional?
 #'
 #' If set to `FALSE` and `arg` is `NULL` then an error is thrown. Otherwise,
 #' `NULL` is considered as valid value.
@@ -331,7 +319,7 @@ assert_logical_scalar <- function(arg, optional = FALSE) {
 #' Checks if an argument is a symbol
 #'
 #' @param arg A function argument to be checked. Must be a `symbol`. See examples.
-#' @param optional Is the checked parameter optional? If set to `FALSE` and `arg`
+#' @param optional Is the checked argument optional? If set to `FALSE` and `arg`
 #' is `NULL` then an error is thrown
 #'
 #'
@@ -405,11 +393,10 @@ assert_expr <- function(arg, optional = FALSE) {
   }
 
   if (is_missing(arg)) {
-    err_msg <- sprintf("Argument `%s` missing, with no default", arg_name(substitute(arg)))
-    abort(err_msg)
+    abort("Argument `arg` missing, with no default")
   }
 
-  if (!is_symbolic(arg)) {
+  if (!(is_call(arg) || is_expression(arg))) {
     err_msg <- sprintf(
       "`%s` must be an expression but is %s",
       arg_name(substitute(arg)),
@@ -442,7 +429,7 @@ assert_expr <- function(arg, optional = FALSE) {
 #' library(rlang)
 #' data(admiral_dm)
 #'
-#' # typical usage in a function as a parameter check
+#' # typical usage in a function as an argument check
 #' example_fun <- function(dat, x) {
 #'   x <- assert_filter_cond(enquo(x))
 #'   filter(dat, !!x)
@@ -459,7 +446,7 @@ assert_filter_cond <- function(arg, optional = FALSE) {
   }
 
   provided <- !is_missing(arg)
-  if (provided & !(is_call(arg) | is_logical(arg))) {
+  if (provided && !(is_call(arg) || is_logical(arg))) {
     err_msg <- sprintf(
       "`%s` must be a filter condition but is %s",
       arg_name(substitute(arg)),
@@ -480,7 +467,7 @@ assert_filter_cond <- function(arg, optional = FALSE) {
 #' @param expect_names If the argument is set to `TRUE`, it is checked if all
 #'   variables are named, e.g., `exprs(APERSDT = APxxSDT, APEREDT = APxxEDT)`.
 #'
-#' @param optional Is the checked parameter optional? If set to `FALSE` and `arg`
+#' @param optional Is the checked argument optional? If set to `FALSE` and `arg`
 #' is `NULL` then an error is thrown
 #'
 #'
@@ -533,62 +520,34 @@ assert_vars <- function(arg, expect_names = FALSE, optional = FALSE) {
 
 #' Is an Argument a List of Order Variables?
 #'
-#' Checks if an argument is a valid list of order variables created using `exprs()`
+#' @description
+#' `r lifecycle::badge("deprecated")`
+#'
+#' This function is *deprecated*, please use `assert_expr_list()` instead.
+#'
+#' Checks if an argument is a valid list of order variables/expressions created
+#' using `exprs()`
 #'
 #' @param arg A function argument to be checked
-#' @param optional Is the checked parameter optional? If set to `FALSE` and `arg`
+#' @param optional Is the checked argument optional? If set to `FALSE` and `arg`
 #' is `NULL` then an error is thrown
 #'
 #'
 #' @return
-#' The function throws an error if `arg` is not a list of variables or `desc()`
-#' calls created using `exprs()` and returns the input invisibly otherwise.
+#' The function throws an error if `arg` is not a list of variables or
+#' expressions created using `exprs()` and returns the input invisibly
+#' otherwise.
 #'
 #' @export
 #'
-#' @keywords assertion
-#' @family assertion
-#' @examples
-#' library(dplyr, warn.conflicts = FALSE)
-#' library(rlang)
-#'
-#' example_fun <- function(by_vars) {
-#'   assert_order_vars(by_vars)
-#' }
-#'
-#' example_fun(exprs(USUBJID, PARAMCD, desc(AVISITN)))
-#'
-#' try(example_fun(quos(USUBJID, PARAMCD)))
-#'
-#' try(example_fun(c("USUBJID", "PARAMCD", "VISIT")))
-#'
-#' try(example_fun(exprs(USUBJID, toupper(PARAMCD), -AVAL)))
+#' @keywords deprecated
+#' @family deprecated
 assert_order_vars <- function(arg, optional = FALSE) {
   assert_logical_scalar(optional)
 
-  default_err_msg <- paste(
-    backquote(arg_name(substitute(arg))),
-    "must be a list of unquoted variable names or `desc()` calls,",
-    "e.g. `exprs(USUBJID, desc(VISITNUM))`"
-  )
+  deprecate_warn("0.4.0", "assert_order_vars()", "assert_expr_list()")
 
-  if (isTRUE(tryCatch(force(arg), error = function(e) TRUE))) {
-    abort(default_err_msg)
-  }
-
-  if (optional && is.null(arg)) {
-    return(invisible(arg))
-  }
-
-  if (!inherits(arg, "list")) {
-    abort(default_err_msg)
-  }
-
-  if (isFALSE(is_order_vars(arg))) {
-    abort(default_err_msg)
-  }
-
-  invisible(arg)
+  assert_expr_list(arg, optional = optional)
 }
 
 #' Is an Argument an Integer Scalar?
@@ -598,7 +557,7 @@ assert_order_vars <- function(arg, optional = FALSE) {
 #' @param arg A function argument to be checked
 #' @param subset A subset of integers that `arg` should be part of. Should be one
 #'   of `"none"` (the default), `"positive"`, `"non-negative"` or `"negative"`.
-#' @param optional Is the checked parameter optional? If set to `FALSE` and `arg`
+#' @param optional Is the checked argument optional? If set to `FALSE` and `arg`
 #'   is `NULL` then an error is thrown
 #'
 #'
@@ -655,7 +614,7 @@ assert_integer_scalar <- function(arg, subset = "none", optional = FALSE) {
 #' Checks if an argument is a numeric vector
 #'
 #' @param arg A function argument to be checked
-#' @param optional Is the checked parameter optional? If set to `FALSE` and `arg`
+#' @param optional Is the checked argument optional? If set to `FALSE` and `arg`
 #' is `NULL` then an error is thrown
 #'
 #'
@@ -697,7 +656,7 @@ assert_numeric_vector <- function(arg, optional = FALSE) {
 #' Checks if an argument is an atomic vector
 #'
 #' @param arg A function argument to be checked
-#' @param optional Is the checked parameter optional? If set to `FALSE` and `arg`
+#' @param optional Is the checked argument optional? If set to `FALSE` and `arg`
 #' is `NULL` then an error is thrown
 #'
 #'
@@ -739,7 +698,7 @@ assert_atomic_vector <- function(arg, optional = FALSE) {
 #' Checks if an argument is an object inheriting from the S3 class specified.
 #' @param arg A function argument to be checked
 #' @param class The S3 class to check for
-#' @param optional Is the checked parameter optional? If set to `FALSE` and `arg`
+#' @param optional Is the checked argument optional? If set to `FALSE` and `arg`
 #'   is `NULL` then an error is thrown
 #'
 #'
@@ -790,7 +749,7 @@ assert_s3_class <- function(arg, class, optional = FALSE) {
 #' @param class The S3 class or type to check for
 #' @param named If set to `TRUE`, an error is issued if not all elements of the
 #'   list are named.
-#' @param optional Is the checked parameter optional? If set to `FALSE` and `arg`
+#' @param optional Is the checked argument optional? If set to `FALSE` and `arg`
 #'   is `NULL` then an error is thrown
 #'
 #'
@@ -863,6 +822,53 @@ assert_list_of <- function(arg, class, named = FALSE, optional = TRUE) {
   invisible(arg)
 }
 
+#' Assert Argument is a Named List or Vector
+#'
+#' Assert that all elements of the argument are named.
+#'
+#' @inheritParams assert_data_frame
+#'
+#' @keywords assertion
+#' @family assertion
+#'
+#' @return
+#' The function throws an error if `arg` is not a named list or vector or
+#' returns the input invisibly otherwise
+#'
+#' @export
+#'
+#' @examples
+#' example_fun <- function(varval_list) {
+#'   assert_named(varval_list)
+#' }
+#'
+#' example_fun(list(var1 = 1, var2 = "x"))
+#'
+#' try(example_fun(list(1, "x")))
+#'
+#' try(example_fun(list(var = 1, "x")))
+assert_named <- function(arg, optional = FALSE) {
+  if (optional && is.null(arg)) {
+    return(invisible(arg))
+  }
+
+  if (length(arg) > 0) {
+    if (is.null(names(arg))) {
+      abort(paste0(
+        "All elements of `", arg_name(substitute(arg)), "` must be named.\n",
+        "No element is named."
+      ))
+    }
+    unnamed <- which(names(arg) == "")
+    if (length(unnamed) > 0) {
+      abort(paste0(
+        "All elements of `", arg_name(substitute(arg)), "` must be named.\n",
+        "The following elements are not named: ", enumerate(unnamed, quote_fun = NULL)
+      ))
+    }
+  }
+}
+
 #' Assert Argument is a Named List of Expressions
 #'
 #' @inheritParams assert_data_frame
@@ -938,14 +944,14 @@ assert_has_variables <- function(dataset, required_vars) {
 
 #' Is Argument a Function?
 #'
-#' Checks if the argument is a function and if all expected parameters are
+#' Checks if the argument is a function and if all expected arguments are
 #' provided by the function.
 #'
 #' @param arg A function argument to be checked
 #'
-#' @param params A character vector of expected parameter names
+#' @param params A character vector of expected argument names
 #'
-#' @param optional Is the checked parameter optional?
+#' @param optional Is the checked argument optional?
 #'
 #' If set to `FALSE` and `arg` is `NULL` then an error is thrown.
 #'
@@ -954,8 +960,8 @@ assert_has_variables <- function(dataset, required_vars) {
 #'
 #'  - if the argument is not a function or
 #'
-#'  - if the function does not provide all parameters as specified for the
-#'  `params` parameter.
+#'  - if the function does not provide all arguments as specified for the
+#'  `params` argument.
 #'
 #' @export
 #'
@@ -999,9 +1005,9 @@ assert_function <- function(arg, params = NULL, optional = FALSE) {
     is_param <- params %in% names(formals(arg))
     if (!all(is_param)) {
       txt <- if (sum(!is_param) == 1L) {
-        "%s is not a parameter of the function specified for `%s`"
+        "%s is not an argument of the function specified for `%s`"
       } else {
-        "%s are not parameters of the function specified for `%s`"
+        "%s are not arguments of the function specified for `%s`"
       }
       err_msg <- sprintf(txt, enumerate(params[!is_param]), arg_name(substitute(arg)))
       abort(err_msg)
@@ -1019,7 +1025,7 @@ assert_function <- function(arg, params = NULL, optional = FALSE) {
 #' @family assertion
 #'
 #' @return
-#' The function throws an error if any elements of `params` is not a parameter of
+#' The function throws an error if any elements of `params` is not an argument of
 #' the function given by `arg`
 #'
 #' @export
@@ -1040,9 +1046,9 @@ assert_function_param <- function(arg, params) {
   is_param <- params %in% names(formals(fun))
   if (!all(is_param)) {
     txt <- if (sum(!is_param) == 1L) {
-      "%s is not a parameter of `%s()`"
+      "%s is not an argument of `%s()`"
     } else {
-      "%s are not parameters of `%s()`"
+      "%s are not arguments of `%s()`"
     }
     err_msg <- sprintf(txt, enumerate(params[!is_param]), arg)
     abort(err_msg)
@@ -1168,15 +1174,15 @@ assert_param_does_not_exist <- function(dataset, param) {
 #' Is an Argument a Variable-Value List?
 #'
 #' Checks if the argument is a list of expressions where the expressions are
-#' variable-value pairs. The value can be a symbol, a string, a numeric, or
-#' `NA`. More general expression are not allowed.
+#' variable-value pairs. The value can be a symbol, a string, a numeric, an
+#' expression, or `NA`.
 #'
 #' @param arg A function argument to be checked
 #' @param required_elements A `character` vector of names that must be present in `arg`
 #' @param accept_expr Should expressions on the right hand side be accepted?
 #' @param accept_var Should unnamed variable names (e.g. `exprs(USUBJID)`) on the
 #'   right hand side be accepted?
-#' @param optional Is the checked parameter optional? If set to `FALSE` and `arg`
+#' @param optional Is the checked argument optional? If set to `FALSE` and `arg`
 #' is `NULL` then an error is thrown.
 #'
 #'
@@ -1200,7 +1206,7 @@ assert_param_does_not_exist <- function(dataset, param) {
 #' try(example_fun(exprs("AE", DTSEQ = AESEQ)))
 assert_varval_list <- function(arg, # nolint
                                required_elements = NULL,
-                               accept_expr = FALSE,
+                               accept_expr = TRUE,
                                accept_var = FALSE,
                                optional = FALSE) {
   assert_logical_scalar(accept_expr)
@@ -1220,7 +1226,7 @@ assert_varval_list <- function(arg, # nolint
     valid_vals <- "a symbol, character scalar, numeric scalar, or `NA`"
   }
 
-  if (!accept_var & (!inherits(arg, "list") || !is_named(arg))) {
+  if (!accept_var && (!inherits(arg, "list") || !is_named(arg))) {
     err_msg <- sprintf(
       paste0(
         "`%s` must be a named list of expressions where each element is ",
@@ -1234,7 +1240,7 @@ assert_varval_list <- function(arg, # nolint
     abort(err_msg)
   }
 
-  if (accept_var & (!contains_vars(arg))) {
+  if (accept_var && (!contains_vars(arg))) {
     err_msg <- sprintf(
       paste0(
         "`%s` must be a list of expressions where each element is ",
@@ -1301,6 +1307,104 @@ assert_varval_list <- function(arg, # nolint
   invisible(arg)
 }
 
+#' Is an Argument a List of Expressions?
+#'
+#' Checks if the argument is a list of expressions.
+#'
+#' @param arg A function argument to be checked
+#' @param required_elements A `character` vector of names that must be present in `arg`
+#' @param named If set to `TRUE`, an error is issued if not all elements of the
+#'   list are named.
+#' @param optional Is the checked argument optional? If set to `FALSE` and `arg`
+#' is `NULL` then an error is thrown.
+#'
+#' @return
+#' The function throws an error if `arg` is not a list of expressions.
+#' Otherwise, the input it returned invisibly.
+#'
+#' @keywords assertion
+#' @family assertion
+#' @export
+#'
+#' @examples
+#' library(rlang)
+#'
+#' example_fun <- function(vars) {
+#'   assert_expr_list(vars)
+#' }
+#' example_fun(exprs(DTHDOM = "AE", DTHSEQ = AESEQ))
+#'
+#' try(example_fun(exprs("AE", DTSEQ = AESEQ, !!list("a"))))
+assert_expr_list <- function(arg, # nolint
+                             required_elements = NULL,
+                             named = FALSE,
+                             optional = FALSE) {
+  assert_logical_scalar(named)
+  assert_logical_scalar(optional)
+  assert_character_vector(required_elements, optional = TRUE)
+
+  if (optional && is.null(arg)) {
+    return(invisible(arg))
+  }
+
+  if (!inherits(arg, "list")) {
+    err_msg <- sprintf(
+      paste0(
+        "`%s` must be a named list of expressions but it is %s\n",
+        "\u2139 To create a list of expressions use `exprs()`"
+      ),
+      arg_name(substitute(arg)),
+      what_is_it(arg)
+    )
+    abort(err_msg)
+  }
+
+  if (named) {
+    assert_named(arg)
+  }
+
+  if (!is.null(required_elements)) {
+    missing_elements <- setdiff(required_elements, names(arg))
+    if (length(missing_elements) >= 1L) {
+      err_msg <- sprintf(
+        "The following required elements are missing in `%s`: %s",
+        arg_name(substitute(arg)),
+        enumerate(missing_elements, quote_fun = squote)
+      )
+      abort(err_msg)
+    }
+  }
+
+  invalids <- !map_lgl(
+    arg,
+    ~ is_call(.x) || is_expression(.x)
+  )
+  invalidargs <- arg[invalids]
+
+  if (any(invalids)) {
+    argname <- arg_name(substitute(arg))
+    abort(
+      paste0(
+        "All elements of `",
+        argname,
+        "` must be an expression.\n",
+        paste0(
+          argname,
+          "[[",
+          if_else(names(invalidargs) == "", as.character(which(invalids)), names(invalidargs)),
+          "]] = ",
+          map_chr(invalidargs, expr_label),
+          " is of type ",
+          map_chr(invalidargs, typeof),
+          collapse = "\n"
+        )
+      )
+    )
+  }
+
+  invisible(arg)
+}
+
 #' Is an Element of a List of Lists/Classes Fulfilling a Condition?
 #'
 #' Checks if the elements of a list of named lists/classes fulfill a certain
@@ -1524,7 +1628,7 @@ assert_date_var <- function(dataset, var, dataset_name = NULL, var_name = NULL)
 #'
 #' @param arg The function argument to be checked
 #'
-#' @param optional Is the checked parameter optional? If set to `FALSE`
+#' @param optional Is the checked argument optional? If set to `FALSE`
 #' and `arg` is `NULL` then the function `assert_date_vector` exits early and throw and error.
 #'
 #' @return
