@@ -84,7 +84,7 @@ test_that("assert_data_frame Test 5: assert_data_frame extract_vars() works as i
   expect_invisible(example_fun(input, order = exprs(SEQ)))
 })
 
-## Test 6: assert_data_frame throws not throw error if extract_vars() has NULL input ----
+## Test 6: assert_data_frame throws error if extract_vars() has NULL input ----
 test_that("assert_data_frame Test 6: assert_data_frame throws error if extract_vars() has NULL input", { # nolint
   input <- tibble::tribble(
     ~STUDYID, ~USUBJID, ~SEQ,
@@ -432,67 +432,33 @@ test_that("assert_symbol Test 25: `assert_symbol` does not throw an error if `ar
 # assert_expr ----
 ## Test 26: `assert_expr` does not throw an error if `arg` is an expression ----
 test_that("assert_expr Test 26: `assert_expr` does not throw an error if `arg` is an expression", {
-  f <- function(var) {
-    v <- enexpr(var)
-  }
-
-  example_fun <- function(arg) {
-    assert_expr(arg)
-  }
-
   expect_invisible(
-    example_fun(
-      f(admiral.test::admiral_dm)
-    )
+    assert_expr(var <- expr(admiral.test::admiral_dm))
   )
 })
 
 ## Test 27: no error if optional is TRUE and `arg` is NULL ----
 test_that("assert_expr Test 27: no error if optional is TRUE and `arg` is NULL", {
-  f <- function(var) {
-    v <- enexpr(var)
-  }
-
-  example_fun <- function(arg) {
-    assert_expr(arg, optional = TRUE)
-  }
-
   expect_invisible(
-    example_fun(
-      f(NULL)
-    )
+    assert_expr(var <- NULL, optional = TRUE)
   )
 })
 
 ## Test 28: `assert_expr` throws an error if `arg` is missing ----
 test_that("assert_expr Test 28: `assert_expr` throws an error if `arg` is missing", {
-  f <- function(var) {
-    v <- enexpr(var)
-  }
-
-  example_fun <- function(arg) {
-    assert_expr(arg)
-  }
-
   expect_error(
-    example_fun(f())
+    assert_expr(),
+    regexp = "Argument `arg` missing, with no default",
+    fixed = TRUE
   )
 })
 
 ## Test 29: `assert_expr` throws an error if `arg` is not an expression ----
 test_that("assert_expr Test 29: `assert_expr` throws an error if `arg` is not an expression", {
-  f <- function(var) {
-    v <- enexpr(var)
-  }
-
-  example_fun <- function(arg) {
-    assert_expr(arg)
-  }
-
   expect_error(
-    example_fun(
-      f(NULL)
-    )
+    assert_expr(var <- c(1, 2)),
+    regexp = "`var` must be an expression but is a double vector",
+    fixed = TRUE
   )
 })
 
@@ -523,34 +489,17 @@ test_that("assert_vars Test 31: error if some elements of `arg` are not unquoted
 })
 
 # assert_order_vars ----
-## Test 32: error if `arg` is not a list variable names or `desc()` ----
-test_that("assert_order_vars Test 32: error if `arg` is not a list variable names or `desc()`", {
-  example_fun <- function(arg) {
-    assert_order_vars(arg)
-  }
-
-  expect_error(
-    example_fun(TRUE)
-  )
-  expect_error(
-    example_fun(1)
-  )
-})
-
-## Test 33: no error if `arg` is NULL and optional is TRUE ----
-test_that("assert_order_vars Test 33: no error if `arg` is NULL and optional is TRUE", {
-  example_fun <- function(arg) {
-    assert_order_vars(arg, optional = TRUE)
-  }
-
-  expect_invisible(
-    example_fun(NULL)
+## Test 32: warn if assert_order_vars() is called ----
+test_that("assert_order_vars Test 32: warn if assert_order_vars() is called", {
+  expect_warning(
+    assert_order_vars(arg <- exprs(USUBJID)),
+    class = "lifecycle_warning_deprecated"
   )
 })
 
 # assert_integer_scalar ----
-## Test 34: no error if `arg` is NULL and optional is TRUE ----
-test_that("assert_integer_scalar Test 34: no error if `arg` is NULL and optional is TRUE", {
+## Test 33: no error if `arg` is NULL and optional is TRUE ----
+test_that("assert_integer_scalar Test 33: no error if `arg` is NULL and optional is TRUE", {
   example_fun <- function(arg) {
     assert_integer_scalar(arg, optional = TRUE)
   }
@@ -560,8 +509,8 @@ test_that("assert_integer_scalar Test 34: no error if `arg` is NULL and optional
   )
 })
 
-## Test 35: error if chosen subset not in subsets ----
-test_that("assert_integer_scalar Test 35: error if chosen subset not in subsets", {
+## Test 34: error if chosen subset not in subsets ----
+test_that("assert_integer_scalar Test 34: error if chosen subset not in subsets", {
   example_fun <- function(arg) {
     assert_integer_scalar(arg, subset = "infinity")
   }
@@ -571,8 +520,8 @@ test_that("assert_integer_scalar Test 35: error if chosen subset not in subsets"
   )
 })
 
-## Test 36: no error if `arg` is in selected subset ----
-test_that("assert_integer_scalar Test 36: no error if `arg` is in selected subset", {
+## Test 35: no error if `arg` is in selected subset ----
+test_that("assert_integer_scalar Test 35: no error if `arg` is in selected subset", {
   example_fun <- function(arg) {
     assert_integer_scalar(arg, subset = "positive")
   }
@@ -582,8 +531,8 @@ test_that("assert_integer_scalar Test 36: no error if `arg` is in selected subse
   )
 })
 
-## Test 37: error if `arg` is not an integer scalar ----
-test_that("assert_integer_scalar Test 37: error if `arg` is not an integer scalar", {
+## Test 36: error if `arg` is not an integer scalar ----
+test_that("assert_integer_scalar Test 36: error if `arg` is not an integer scalar", {
   example_fun <- function(arg) {
     assert_integer_scalar(arg)
   }
@@ -597,8 +546,8 @@ test_that("assert_integer_scalar Test 37: error if `arg` is not an integer scala
 })
 
 # assert_numeric_vector ----
-## Test 38: no error if `arg` is NULL and optional is TRUE ----
-test_that("assert_numeric_vector Test 38: no error if `arg` is NULL and optional is TRUE", {
+## Test 37: no error if `arg` is NULL and optional is TRUE ----
+test_that("assert_numeric_vector Test 37: no error if `arg` is NULL and optional is TRUE", {
   example_fun <- function(arg) {
     assert_numeric_vector(arg, optional = TRUE)
   }
@@ -609,8 +558,8 @@ test_that("assert_numeric_vector Test 38: no error if `arg` is NULL and optional
 })
 
 # assert_integer_scalar ----
-## Test 39: error if `arg` is not an integer scalar ----
-test_that("assert_integer_scalar Test 39: error if `arg` is not an integer scalar", {
+## Test 38: error if `arg` is not an integer scalar ----
+test_that("assert_integer_scalar Test 38: error if `arg` is not an integer scalar", {
   example_fun <- function(arg) {
     assert_numeric_vector(arg)
   }
@@ -623,8 +572,8 @@ test_that("assert_integer_scalar Test 39: error if `arg` is not an integer scala
 })
 
 # assert_s3_class ----
-## Test 40: error if `arg` is not an object of a specific class S3 ----
-test_that("assert_s3_class Test 40: error if `arg` is not an object of a specific class S3", {
+## Test 39: error if `arg` is not an object of a specific class S3 ----
+test_that("assert_s3_class Test 39: error if `arg` is not an object of a specific class S3", {
   example_fun <- function(arg) {
     assert_s3_class(arg, "factor")
   }
@@ -632,8 +581,8 @@ test_that("assert_s3_class Test 40: error if `arg` is not an object of a specifi
   expect_error(example_fun("test"))
 })
 
-## Test 41: no error if `arg` is NULL and optional is TRUE ----
-test_that("assert_s3_class Test 41: no error if `arg` is NULL and optional is TRUE", {
+## Test 40: no error if `arg` is NULL and optional is TRUE ----
+test_that("assert_s3_class Test 40: no error if `arg` is NULL and optional is TRUE", {
   example_fun <- function(arg) {
     assert_s3_class(arg, class = "factor", optional = TRUE)
   }
@@ -643,8 +592,8 @@ test_that("assert_s3_class Test 41: no error if `arg` is NULL and optional is TR
   )
 })
 
-## Test 42: error if `arg` is NULL and optional is FALSE ----
-test_that("assert_s3_class Test 42: error if `arg` is NULL and optional is FALSE", {
+## Test 41: error if `arg` is NULL and optional is FALSE ----
+test_that("assert_s3_class Test 41: error if `arg` is NULL and optional is FALSE", {
   example_fun <- function(arg) {
     assert_s3_class(arg, class = "factor", optional = FALSE)
   }
@@ -656,8 +605,8 @@ test_that("assert_s3_class Test 42: error if `arg` is NULL and optional is FALSE
   )
 })
 
-## Test 43: no error if `arg` is an object of a specific class S3 ----
-test_that("assert_s3_class Test 43: no error if `arg` is an object of a specific class S3", {
+## Test 42: no error if `arg` is an object of a specific class S3 ----
+test_that("assert_s3_class Test 42: no error if `arg` is an object of a specific class S3", {
   example_fun <- function(arg) {
     assert_s3_class(arg, "factor")
   }
@@ -666,8 +615,8 @@ test_that("assert_s3_class Test 43: no error if `arg` is an object of a specific
 })
 
 # assert_list_of ----
-## Test 44: error if `arg` is not a list of specific class S3 objects ----
-test_that("assert_list_of Test 44: error if `arg` is not a list of specific class S3 objects", {
+## Test 43: error if `arg` is not a list of specific class S3 objects ----
+test_that("assert_list_of Test 43: error if `arg` is not a list of specific class S3 objects", {
   example_fun <- function(arg) {
     assert_list_of(arg, "factor")
   }
@@ -675,8 +624,8 @@ test_that("assert_list_of Test 44: error if `arg` is not a list of specific clas
   expect_error(example_fun(list("test")))
 })
 
-## Test 45: no error if `arg` is NULL and optional is TRUE ----
-test_that("assert_list_of Test 45: no error if `arg` is NULL and optional is TRUE", {
+## Test 44: no error if `arg` is NULL and optional is TRUE ----
+test_that("assert_list_of Test 44: no error if `arg` is NULL and optional is TRUE", {
   example_fun <- function(arg) {
     assert_list_of(arg, class = "factor", optional = TRUE)
   }
@@ -686,8 +635,8 @@ test_that("assert_list_of Test 45: no error if `arg` is NULL and optional is TRU
   )
 })
 
-## Test 46: error if `arg` is NULL and optional is FALSE ----
-test_that("assert_list_of Test 46: error if `arg` is NULL and optional is FALSE", {
+## Test 45: error if `arg` is NULL and optional is FALSE ----
+test_that("assert_list_of Test 45: error if `arg` is NULL and optional is FALSE", {
   example_fun <- function(arg) {
     assert_list_of(arg, class = "factor", optional = FALSE)
   }
@@ -699,8 +648,8 @@ test_that("assert_list_of Test 46: error if `arg` is NULL and optional is FALSE"
   )
 })
 
-## Test 47: no error if `arg` is a list of specific class S3 objects ----
-test_that("assert_list_of Test 47: no error if `arg` is a list of specific class S3 objects", {
+## Test 46: no error if `arg` is a list of specific class S3 objects ----
+test_that("assert_list_of Test 46: no error if `arg` is a list of specific class S3 objects", {
   example_fun <- function(arg) {
     assert_list_of(arg, "factor")
   }
@@ -712,8 +661,8 @@ test_that("assert_list_of Test 47: no error if `arg` is a list of specific class
   )
 })
 
-## Test 48: error if `arg` is not a named list (no elements named) ----
-test_that("assert_list_of Test 48: error if `arg` is not a named list (no elements named)", {
+## Test 47: error if `arg` is not a named list (no elements named) ----
+test_that("assert_list_of Test 47: error if `arg` is not a named list (no elements named)", {
   expect_error(
     assert_list_of(mylist <- list(1, 2, 3), class = "numeric", named = TRUE),
     paste(
@@ -724,8 +673,8 @@ test_that("assert_list_of Test 48: error if `arg` is not a named list (no elemen
   )
 })
 
-## Test 49: error if `arg` is not a named list (some elements named) ----
-test_that("assert_list_of Test 49: error if `arg` is not a named list (some elements named)", {
+## Test 48: error if `arg` is not a named list (some elements named) ----
+test_that("assert_list_of Test 48: error if `arg` is not a named list (some elements named)", {
   expect_error(
     assert_list_of(mylist <- list(1, 2, 3, d = 4), class = "numeric", named = TRUE),
     paste(
@@ -736,16 +685,35 @@ test_that("assert_list_of Test 49: error if `arg` is not a named list (some elem
   )
 })
 
-## Test 50: no error if `arg` is a named list ----
-test_that("assert_list_of Test 50: no error if `arg` is a named list", {
+## Test 49: no error if `arg` is a named list ----
+test_that("assert_list_of Test 49: no error if `arg` is a named list", {
   expect_invisible(
     assert_list_of(mylist <- list(a = 1, b = 2, c = 3), class = "numeric", named = TRUE)
   )
 })
 
+# assert_named ----
+## Test 50: no error if arg is NULL and optional = TRUE ----
+test_that("assert_named Test 50: no error if arg is NULL and optional = TRUE", {
+  expect_invisible(assert_named(arg <- NULL, optional = TRUE))
+})
+
+## Test 51: error if no elements are named ----
+test_that("assert_named Test 51: error if no elements are named", {
+  expect_error(
+    assert_named(arg <- c(1, 2)),
+    regexp = paste(
+      "All elements of `arg` must be named.",
+      "No element is named.",
+      sep = "\n"
+    ),
+    fixed = TRUE
+  )
+})
+
 # assert_named_exprs ----
-## Test 51: error if `arg` is not a named list of expressions ----
-test_that("assert_named_exprs Test 51: error if `arg` is not a named list of expressions", {
+## Test 52: error if `arg` is not a named list of expressions ----
+test_that("assert_named_exprs Test 52: error if `arg` is not a named list of expressions", {
   example_fun <- function(arg) {
     assert_named_exprs(arg)
   }
@@ -759,8 +727,8 @@ test_that("assert_named_exprs Test 51: error if `arg` is not a named list of exp
   expect_error(example_fun(arg))
 })
 
-## Test 52: no error if `arg` is NULL and optional is TRUE ----
-test_that("assert_named_exprs Test 52: no error if `arg` is NULL and optional is TRUE", {
+## Test 53: no error if `arg` is NULL and optional is TRUE ----
+test_that("assert_named_exprs Test 53: no error if `arg` is NULL and optional is TRUE", {
   example_fun <- function(arg) {
     assert_named_exprs(arg, optional = TRUE)
   }
@@ -770,8 +738,8 @@ test_that("assert_named_exprs Test 52: no error if `arg` is NULL and optional is
   )
 })
 
-## Test 53: no error if `arg` is a named list of expressions ----
-test_that("assert_named_exprs Test 53: no error if `arg` is a named list of expressions", {
+## Test 54: no error if `arg` is a named list of expressions ----
+test_that("assert_named_exprs Test 54: no error if `arg` is a named list of expressions", {
   example_fun <- function(arg) {
     assert_named_exprs(arg)
   }
@@ -784,8 +752,8 @@ test_that("assert_named_exprs Test 53: no error if `arg` is a named list of expr
 })
 
 # assert_function ----
-## Test 54: error if `arg` is not a function ----
-test_that("assert_function Test 54: error if `arg` is not a function", {
+## Test 55: error if `arg` is not a function ----
+test_that("assert_function Test 55: error if `arg` is not a function", {
   example_fun <- function(arg) {
     assert_function(arg)
   }
@@ -794,8 +762,8 @@ test_that("assert_function Test 54: error if `arg` is not a function", {
   expect_error(example_fun())
 })
 
-## Test 55: no error if `arg` is NULL and optional is TRUE ----
-test_that("assert_function Test 55: no error if `arg` is NULL and optional is TRUE", {
+## Test 56: no error if `arg` is NULL and optional is TRUE ----
+test_that("assert_function Test 56: no error if `arg` is NULL and optional is TRUE", {
   example_fun <- function(arg) {
     assert_function(arg, optional = TRUE)
   }
@@ -805,8 +773,8 @@ test_that("assert_function Test 55: no error if `arg` is NULL and optional is TR
   )
 })
 
-## Test 56: no error if `arg` is a function with all parameters defined ----
-test_that("assert_function Test 56: no error if `arg` is a function with all parameters defined", {
+## Test 57: no error if `arg` is a function with all parameters defined ----
+test_that("assert_function Test 57: no error if `arg` is a function with all parameters defined", {
   example_fun <- function(arg) {
     assert_function(arg, params = c("x"))
   }
@@ -814,8 +782,8 @@ test_that("assert_function Test 56: no error if `arg` is a function with all par
   expect_invisible(example_fun(mean))
 })
 
-## Test 57: error if  `params`  is missing with no default ----
-test_that("assert_function Test 57: error if  `params`  is missing with no default", {
+## Test 58: error if  `params`  is missing with no default ----
+test_that("assert_function Test 58: error if  `params`  is missing with no default", {
   example_fun <- function(arg) {
     assert_function(arg, params = c("x"))
   }
@@ -831,8 +799,8 @@ test_that("assert_function Test 57: error if  `params`  is missing with no defau
 
 
 # assert_function_param ----
-## Test 58: no error if `arg` is a parameter of a function ----
-test_that("assert_function_param Test 58: no error if `arg` is a parameter of a function", {
+## Test 59: no error if `arg` is a parameter of a function ----
+test_that("assert_function_param Test 59: no error if `arg` is a parameter of a function", {
   hello <- function(name) {
     print(sprintf("Hello %s", name))
   }
@@ -840,8 +808,8 @@ test_that("assert_function_param Test 58: no error if `arg` is a parameter of a
   expect_invisible(assert_function_param("hello", "name"))
 })
 
-## Test 59: error if expected function parameters are missing ----
-test_that("assert_function_param Test 59: error if expected function parameters are missing", {
+## Test 60: error if expected function parameters are missing ----
+test_that("assert_function_param Test 60: error if expected function parameters are missing", {
   hello <- function(name) {
     print(sprintf("Hello %s", name))
   }
@@ -851,8 +819,8 @@ test_that("assert_function_param Test 59: error if expected function parameters
 })
 
 # assert_unit ----
-## Test 60: no error if the parameter is provided in the expected unit ----
-test_that("assert_unit Test 60: no error if the parameter is provided in the expected unit", {
+## Test 61: no error if the parameter is provided in the expected unit ----
+test_that("assert_unit Test 61: no error if the parameter is provided in the expected unit", {
   advs <- tibble::tribble(
     ~USUBJID, ~VSTESTCD, ~VSTRESN, ~VSSTRESU, ~PARAMCD, ~AVAL,
     "P01",    "WEIGHT",      80.1, "kg",      "WEIGHT",  80.1,
@@ -864,8 +832,8 @@ test_that("assert_unit Test 60: no error if the parameter is provided in the exp
   )
 })
 
-## Test 61: error if there are multiple units in the input dataset ----
-test_that("assert_unit Test 61: error if there are multiple units in the input dataset", {
+## Test 62: error if there are multiple units in the input dataset ----
+test_that("assert_unit Test 62: error if there are multiple units in the input dataset", {
   advs <- tibble::tribble(
     ~USUBJID, ~VSTESTCD, ~VSTRESN, ~VSSTRESU, ~PARAMCD, ~AVAL,
     "P01",    "WEIGHT",      80.1, "kg",      "WEIGHT",  80.1,
@@ -877,8 +845,8 @@ test_that("assert_unit Test 61: error if there are multiple units in the input d
   )
 })
 
-## Test 62: error if unexpected unit in the input dataset ----
-test_that("assert_unit Test 62: error if unexpected unit in the input dataset", {
+## Test 63: error if unexpected unit in the input dataset ----
+test_that("assert_unit Test 63: error if unexpected unit in the input dataset", {
   advs <- tibble::tribble(
     ~USUBJID, ~VSTESTCD, ~VSTRESN, ~VSSTRESU, ~PARAMCD, ~AVAL,
     "P01",    "WEIGHT",      80.1, "kg",      "WEIGHT",  80.1,
@@ -891,8 +859,8 @@ test_that("assert_unit Test 62: error if unexpected unit in the input dataset",
 })
 
 # assert_param_does_not_exist ----
-## Test 63: error if parameter exists in the input dataset ----
-test_that("assert_param_does_not_exist Test 63: error if parameter exists in the input dataset", {
+## Test 64: error if parameter exists in the input dataset ----
+test_that("assert_param_does_not_exist Test 64: error if parameter exists in the input dataset", {
   advs <- tibble::tribble(
     ~USUBJID, ~VSTESTCD, ~VSTRESN, ~VSSTRESU, ~PARAMCD, ~AVAL,
     "P01",    "WEIGHT",      80.1, "kg",      "WEIGHT",  80.1,
@@ -904,8 +872,8 @@ test_that("assert_param_does_not_exist Test 63: error if parameter exists in the
   )
 })
 
-## Test 64: no error if the parameter exists in the dataset ----
-test_that("assert_param_does_not_exist Test 64: no error if the parameter exists in the dataset", {
+## Test 65: no error if the parameter exists in the dataset ----
+test_that("assert_param_does_not_exist Test 65: no error if the parameter exists in the dataset", {
   advs <- tibble::tribble(
     ~USUBJID, ~VSTESTCD, ~VSTRESN, ~VSSTRESU, ~PARAMCD, ~AVAL,
     "P01",    "WEIGHT",      80.1, "kg",      "WEIGHT",  80.1,
@@ -918,8 +886,8 @@ test_that("assert_param_does_not_exist Test 64: no error if the parameter exists
 })
 
 # assert_varval_list ----
-## Test 65: error if `arg` is not a list of var-value expressions ----
-test_that("assert_varval_list Test 65: error if `arg` is not a list of var-value expressions", {
+## Test 66: error if `arg` is not a list of var-value expressions ----
+test_that("assert_varval_list Test 66: error if `arg` is not a list of var-value expressions", {
   example_fun <- function(arg) {
     assert_varval_list(arg, accept_var = FALSE)
   }
@@ -929,8 +897,8 @@ test_that("assert_varval_list Test 65: error if `arg` is not a list of var-value
   )
 })
 
-## Test 66: error if `arg` is not a list of var-value expressions ----
-test_that("assert_varval_list Test 66: error if `arg` is not a list of var-value expressions", {
+## Test 67: error if `arg` is not a list of var-value expressions ----
+test_that("assert_varval_list Test 67: error if `arg` is not a list of var-value expressions", {
   example_fun <- function(arg) {
     assert_varval_list(arg, accept_var = TRUE)
   }
@@ -940,8 +908,8 @@ test_that("assert_varval_list Test 66: error if `arg` is not a list of var-value
   )
 })
 
-## Test 67: error if `required_elements` are missing from `arg` ----
-test_that("assert_varval_list Test 67: error if `required_elements` are missing from `arg`", {
+## Test 68: error if `required_elements` are missing from `arg` ----
+test_that("assert_varval_list Test 68: error if `required_elements` are missing from `arg`", {
   example_fun <- function(arg) {
     assert_varval_list(arg, required_elements = "DTHDOM")
   }
@@ -951,8 +919,8 @@ test_that("assert_varval_list Test 67: error if `required_elements` are missing
   )
 })
 
-## Test 68: no error if `arg` is NULL and optional is TRUE ----
-test_that("assert_varval_list Test 68: no error if `arg` is NULL and optional is TRUE", {
+## Test 69: no error if `arg` is NULL and optional is TRUE ----
+test_that("assert_varval_list Test 69: no error if `arg` is NULL and optional is TRUE", {
   example_fun <- function(arg) {
     assert_varval_list(arg, optional = TRUE)
   }
@@ -962,8 +930,8 @@ test_that("assert_varval_list Test 68: no error if `arg` is NULL and optional is
   )
 })
 
-## Test 69: error if `accept_expr` is TRUE and value is invalid ----
-test_that("assert_varval_list Test 69: error if `accept_expr` is TRUE and value is invalid", {
+## Test 70: error if `accept_expr` is TRUE and value is invalid ----
+test_that("assert_varval_list Test 70: error if `accept_expr` is TRUE and value is invalid", {
   example_fun <- function(arg) {
     assert_varval_list(arg, accept_expr = TRUE)
   }
@@ -973,8 +941,8 @@ test_that("assert_varval_list Test 69: error if `accept_expr` is TRUE and value
   )
 })
 
-## Test 70: error if `accept_expr` is FALSE and value is invalid ----
-test_that("assert_varval_list Test 70: error if `accept_expr` is FALSE and value is invalid", {
+## Test 71: error if `accept_expr` is FALSE and value is invalid ----
+test_that("assert_varval_list Test 71: error if `accept_expr` is FALSE and value is invalid", {
   example_fun <- function(arg) {
     assert_varval_list(arg, accept_expr = FALSE)
   }
@@ -984,8 +952,8 @@ test_that("assert_varval_list Test 70: error if `accept_expr` is FALSE and value
   )
 })
 
-## Test 71: no error if an argument is a variable-value list ----
-test_that("assert_varval_list Test 71: no error if an argument is a variable-value list", {
+## Test 72: no error if an argument is a variable-value list ----
+test_that("assert_varval_list Test 72: no error if an argument is a variable-value list", {
   example_fun <- function(arg) {
     assert_varval_list(arg)
   }
@@ -995,9 +963,67 @@ test_that("assert_varval_list Test 71: no error if an argument is a variable-val
   )
 })
 
+# assert_expr_list ----
+## Test 73: error if `arg` is not a list of expressions ----
+test_that("assert_expr_list Test 73: error if `arg` is not a list of expressions", {
+  expect_error(
+    assert_expr_list(arg <- c("USUBJID", "PARAMCD", "VISIT")),
+    regexp = "`arg` must be a named list of expressions but it is a",
+    fixed = TRUE
+  )
+})
+
+## Test 74: error if `arg` is not a named list of expressions ----
+test_that("assert_expr_list Test 74: error if `arg` is not a named list of expressions", {
+  expect_error(
+    assert_expr_list(arg <- exprs(USUBJID, PARAMCD, NULL), named = TRUE),
+    regexp = "All elements of `arg` must be named.",
+    fixed = TRUE
+  )
+})
+
+## Test 75: error if `required_elements` are missing from `arg` ----
+test_that("assert_expr_list Test 75: error if `required_elements` are missing from `arg`", {
+  expect_error(
+    assert_expr_list(
+      arg <- exprs(DTHSEQ = AESEQ),
+      required_elements = "DTHDOM"
+    ),
+    regexp = "The following required elements are missing in `arg`: 'DTHDOM'",
+    fixed = TRUE
+  )
+})
+
+## Test 76: no error if `arg` is NULL and optional is TRUE ----
+test_that("assert_expr_list Test 76: no error if `arg` is NULL and optional is TRUE", {
+  expect_invisible(
+    assert_expr_list(NULL, optional = TRUE)
+  )
+})
+
+## Test 77: error if element is invalid ----
+test_that("assert_expr_list Test 77: error if element is invalid", {
+  expect_error(
+    assert_expr_list(arg <- exprs(DTHSEQ = !!mean)),
+    regexp = "All elements of `arg` must be an expression.",
+    fixed = TRUE
+  )
+})
+
+## Test 78: no error if argument is valid ----
+test_that("assert_expr_list Test 78: no error if argument is valid", {
+  expect_invisible(
+    assert_expr_list(arg <- exprs(
+      DTHDOM = "AE",
+      DTHSEQ = AESEQ,
+      DTHVAR = if_else(!is.na(AEDECOD), "AEDECOD", NA)
+    ))
+  )
+})
+
 # assert_list_element ----
-## Test 72: no error if the elements fulfill a certain condition ----
-test_that("assert_list_element Test 72: no error if the elements fulfill a certain condition", {
+## Test 79: no error if the elements fulfill a certain condition ----
+test_that("assert_list_element Test 79: no error if the elements fulfill a certain condition", {
   expect_invisible(
     assert_list_element(
       list(
@@ -1011,8 +1037,8 @@ test_that("assert_list_element Test 72: no error if the elements fulfill a certa
   )
 })
 
-## Test 73: error if the elements do not fulfill the condition ----
-test_that("assert_list_element Test 73: error if the elements do not fulfill the condition", {
+## Test 80: error if the elements do not fulfill the condition ----
+test_that("assert_list_element Test 80: error if the elements do not fulfill the condition", {
   expect_error(
     assert_list_element(
       input <- list(
@@ -1029,23 +1055,25 @@ test_that("assert_list_element Test 73: error if the elements do not fulfill the
 })
 
 # assert_one_to_one ----
-## Test 74: error if there is a one to many mapping ----
-test_that("assert_one_to_one Test 74: error if there is a one to many mapping", {
+## Test 81: error if there is a one to many mapping ----
+test_that("assert_one_to_one Test 81: error if there is a one to many mapping", {
   expect_error(
     assert_one_to_one(admiral.test::admiral_dm, exprs(DOMAIN), exprs(USUBJID))
   )
+  admiraldev_environment$one_to_many <- NULL
 })
 
-## Test 75: error if there is a many to one mapping ----
-test_that("assert_one_to_one Test 75: error if there is a many to one mapping", {
+## Test 82: error if there is a many to one mapping ----
+test_that("assert_one_to_one Test 82: error if there is a many to one mapping", {
   expect_error(
     assert_one_to_one(admiral.test::admiral_dm, exprs(USUBJID), exprs(DOMAIN))
   )
+  admiraldev_environment$many_to_one <- NULL
 })
 
 # assert_date_var ----
-## Test 76: error if variable is not a date or datetime variable ----
-test_that("assert_date_var Test 76: error if variable is not a date or datetime variable", {
+## Test 83: error if variable is not a date or datetime variable ----
+test_that("assert_date_var Test 83: error if variable is not a date or datetime variable", {
   example_fun <- function(dataset, var) {
     var <- assert_symbol(enexpr(var))
     assert_date_var(dataset = dataset, var = !!var)
@@ -1066,18 +1094,18 @@ test_that("assert_date_var Test 76: error if variable is not a date or datetime
 })
 
 # assert_date_vector ----
-## Test 77: returns error if input vector is not a date formatted ----
-test_that("assert_date_vector Test 77: returns error if input vector is not a date formatted", {
+## Test 84: returns error if input vector is not a date formatted ----
+test_that("assert_date_vector Test 84: returns error if input vector is not a date formatted", {
   expect_error(assert_date_vector("2018-08-23"))
 })
 
-## Test 78: returns invisible if input is date formatted ----
-test_that("assert_date_vector Test 78: returns invisible if input is date formatted", {
+## Test 85: returns invisible if input is date formatted ----
+test_that("assert_date_vector Test 85: returns invisible if input is date formatted", {
   expect_invisible(assert_date_vector(as.Date("2022-10-25")))
 })
 
-## Test 79: no error if `arg` is NULL and optional is TRUE ----
-test_that("assert_date_vector Test 79: no error if `arg` is NULL and optional is TRUE", {
+## Test 86: no error if `arg` is NULL and optional is TRUE ----
+test_that("assert_date_vector Test 86: no error if `arg` is NULL and optional is TRUE", {
   example_fun <- function(arg) {
     assert_date_vector(arg, optional = TRUE)
   }
@@ -1087,8 +1115,8 @@ test_that("assert_date_vector Test 79: no error if `arg` is NULL and optional is
   )
 })
 
-## Test 80: error if `arg` is NULL and optional is FALSE ----
-test_that("assert_date_vector Test 80: error if `arg` is NULL and optional is FALSE", {
+## Test 87: error if `arg` is NULL and optional is FALSE ----
+test_that("assert_date_vector Test 87: error if `arg` is NULL and optional is FALSE", {
   example_fun <- function(arg) {
     assert_date_vector(arg, optional = FALSE)
   }
@@ -1102,22 +1130,22 @@ test_that("assert_date_vector Test 80: error if `arg` is NULL and optional is FA
 
 
 # assert_atomic_vector ----
-## Test 81: error if input is not atomic vector ----
-test_that("assert_atomic_vector Test 81: error if input is not atomic vector", {
+## Test 88: error if input is not atomic vector ----
+test_that("assert_atomic_vector Test 88: error if input is not atomic vector", {
   x <- list("a", "a", "b", "c", "d", "d", 1, 1, 4)
   expect_error(assert_atomic_vector(x))
 })
 
 # assert_same_type ----
-## Test 82: no error if same type ----
-test_that("assert_same_type Test 82: no error if same type", {
+## Test 89: no error if same type ----
+test_that("assert_same_type Test 89: no error if same type", {
   true_value <- "Y"
   false_value <- "N"
   expect_invisible(assert_same_type(true_value, false_value))
 })
 
-## Test 83: error if different type ----
-test_that("assert_same_type Test 83: error if different type", {
+## Test 90: error if different type ----
+test_that("assert_same_type Test 90: error if different type", {
   true_value <- "Y"
   false_value <- "N"
   missing_value <- 0
@@ -1136,8 +1164,8 @@ test_that("assert_same_type Test 83: error if different type", {
   )
 })
 
-## Test 84: works as intended ----
-test_that("assert_same_type Test 84: works as intended", {
+## Test 91: works as intended ----
+test_that("assert_same_type Test 91: works as intended", {
   expect_equal(
     valid_time_units(),
     c("years", "months", "days", "hours", "minutes", "seconds")
