@@ -1,9 +1,9 @@
 # quo_c ----
 ## Test 1: issues deprecation warning ----
 test_that("quo_c Test 1: issues deprecation warning", {
-  expect_warning(
+  expect_error(
     quo_c(quo(USUBJID), quo(STUDYID)),
-    class = "lifecycle_warning_deprecated"
+    class = "lifecycle_error_deprecated"
   )
 })
 
@@ -12,13 +12,13 @@ test_that("quo_c Test 2: `quo_c` works in concatenating and indexing quosures",
   x <- quo(USUBJID)
   y <- quo(STUDYID)
 
-  expect_equal(
-    expected = quo(USUBJID),
-    object = quo_c(x, NULL, y)[[1]]
+  expect_error(
+    quo_c(x, NULL, y)[[1]],
+    class = "lifecycle_error_deprecated"
   )
-  expect_equal(
-    expected = quo(STUDYID),
-    object = quo_c(x, NULL, y)[[2]]
+  expect_error(
+    object = quo_c(x, NULL, y)[[2]],
+    class = "lifecycle_error_deprecated"
   )
 })
 
@@ -27,7 +27,8 @@ test_that("quo_c Test 3: `quo_c` returns error if non-quosures are input", {
   USUBJID <- "01-701-1015" # nolint
 
   expect_error(
-    object = quo_c(quo(USUBJID), USUBJID)
+    object = quo_c(quo(USUBJID), USUBJID),
+    class = "lifecycle_error_deprecated"
   )
 })
 
@@ -47,28 +48,44 @@ test_that("expr_c Test 4: concatenating and indexing expressions", {
   )
 })
 
-## Test 5: returns error if non-expressions are input ----
-test_that("expr_c Test 5: returns error if non-expressions are input", {
+## Test 5: concatenating named list of expressions ----
+test_that("expr_c Test 5: concatenating named list of expressions", {
+  expect_equal(
+    expected = exprs(PARAMCD = "DOSE", PARAMN = 1),
+    object = expr_c(exprs(PARAMCD = "DOSE", PARAMN = 1, NULL))
+  )
+})
+
+## Test 6: concatenating list and single expression ----
+test_that("expr_c Test 6: concatenating list and single expression", {
+  expect_equal(
+    expected = exprs(PARAMCD, PARAM, AVAL),
+    object = expr_c(exprs(PARAMCD, PARAM), expr(AVAL))
+  )
+})
+
+## Test 7: returns error if non-expressions are input ----
+test_that("expr_c Test 7: returns error if non-expressions are input", {
   expect_error(
     object = expr_c(expr(USUBJID), mean)
   )
 })
 
 # quo_not_missing ----
-## Test 6: issues deprecation warning ----
-test_that("quo_not_missing Test 6: issues deprecation warning", {
+## Test 8: issues deprecation warning ----
+test_that("quo_not_missing Test 8: issues deprecation warning", {
   test_fun <- function(x) {
     x <- enquo(x)
     !isTRUE(quo_not_missing(x))
   }
-  expect_warning(
+  expect_error(
     test_fun(my_variable),
-    class = "lifecycle_warning_deprecated"
+    class = "lifecycle_error_deprecated"
   )
 })
 
-## Test 7: `quo_not_missing` throws an Error if missing argument ----
-test_that("quo_not_missing Test 7: `quo_not_missing` throws an Error if missing argument", {
+## Test 9: `quo_not_missing` throws an Error if missing argument ----
+test_that("quo_not_missing Test 9: `quo_not_missing` throws an Error if missing argument", {
   test_fun <- function(x) {
     x <- enquo(x)
     isTrue(quo_not_missing(x))
@@ -77,8 +94,8 @@ test_that("quo_not_missing Test 7: `quo_not_missing` throws an Error if missing
 })
 
 # replace_values_by_names ----
-## Test 8: names of quosures replace value ----
-test_that("replace_values_by_names Test 8: names of quosures replace value", {
+## Test 10: names of expressions replace value ----
+test_that("replace_values_by_names Test 10: names of expressions replace value", {
   z <- exprs(USUBJID, STUDYID)
 
   z_noname <- replace_values_by_names(z)
@@ -105,17 +122,28 @@ test_that("replace_values_by_names Test 8: names of quosures replace value", {
   )
 })
 
-## Test 9: warning if quosures argument is used ----
-test_that("replace_values_by_names Test 9: warning if quosures argument is used", {
-  expect_warning(
+## Test 11: names of argument is NULL ----
+test_that("replace_values_by_names Test 11: names of argument is NULL", {
+  z <- exprs(USUBJID, STUDYID)
+  names(z) <- NULL
+
+  expect_equal(
+    expected = z,
+    object = replace_values_by_names(z)
+  )
+})
+
+## Test 12: warning if quosures argument is used ----
+test_that("replace_values_by_names Test 12: warning if quosures argument is used", {
+  expect_error(
     replace_values_by_names(quosures = rlang::quos(STUDYID, USUBJID)),
-    class = "lifecycle_warning_deprecated"
+    class = "lifecycle_error_deprecated"
   )
 })
 
 # replace_symbol_in_quo ----
-## Test 10: error if called ----
-test_that("replace_symbol_in_quo Test 10: error if called", {
+## Test 13: error if called ----
+test_that("replace_symbol_in_quo Test 13: error if called", {
   expect_error(
     replace_symbol_in_quo(),
     class = "lifecycle_error_deprecated"
@@ -123,8 +151,8 @@ test_that("replace_symbol_in_quo Test 10: error if called", {
 })
 
 # replace_symbol_in_expr ----
-## Test 11: symbol is replaced ----
-test_that("replace_symbol_in_expr Test 11: symbol is replaced", {
+## Test 14: symbol is replaced ----
+test_that("replace_symbol_in_expr Test 14: symbol is replaced", {
   expect_equal(
     expected = expr(AVAL.join),
     object = replace_symbol_in_expr(
@@ -135,8 +163,8 @@ test_that("replace_symbol_in_expr Test 11: symbol is replaced", {
   )
 })
 
-## Test 12: partial match is not replaced ----
-test_that("replace_symbol_in_expr Test 12: partial match is not replaced", {
+## Test 15: partial match is not replaced ----
+test_that("replace_symbol_in_expr Test 15: partial match is not replaced", {
   expect_equal(
     expected = expr(AVALC),
     object = replace_symbol_in_expr(
@@ -147,8 +175,8 @@ test_that("replace_symbol_in_expr Test 12: partial match is not replaced", {
   )
 })
 
-## Test 13: symbol in expression is replaced ----
-test_that("replace_symbol_in_expr Test 13: symbol in expression is replaced", {
+## Test 16: symbol in expression is replaced ----
+test_that("replace_symbol_in_expr Test 16: symbol in expression is replaced", {
   expect_equal(
     expected = expr(desc(AVAL.join)),
     object = replace_symbol_in_expr(
@@ -160,8 +188,8 @@ test_that("replace_symbol_in_expr Test 13: symbol in expression is replaced", {
 })
 
 # add_suffix_to_vars ----
-## Test 14: with single variable ----
-test_that("add_suffix_to_vars Test 14: with single variable", {
+## Test 17: with single variable ----
+test_that("add_suffix_to_vars Test 17: with single variable", {
   expect_equal(
     expected = exprs(ADT, desc(AVAL.join), AVALC),
     object = add_suffix_to_vars(
@@ -172,8 +200,8 @@ test_that("add_suffix_to_vars Test 14: with single variable", {
   )
 })
 
-## Test 15: with more than one variable ----
-test_that("add_suffix_to_vars Test 15: with more than one variable", {
+## Test 18: with more than one variable ----
+test_that("add_suffix_to_vars Test 18: with more than one variable", {
   expect_equal(
     expected = exprs(ADT, desc(AVAL.join), AVALC.join),
     object = add_suffix_to_vars(
